@@ -269,16 +269,19 @@ class OIDCAuthBackend(BaseAuthBackend):
         try:
             email = user_info["email"]
         except KeyError:
-            messages.error(self.request,
-                           _("Error: Email missing from keycloak roles"), )
-            return redirect(reverse("control:auth.login"))
+            raise SuspiciousOperation("Error: Email missing from keycloak roles")
+            # messages.error(self.request,
+            #                _("Error: Email missing from keycloak roles"), )
+            # return redirect(reverse("control:auth.login"))
 
         try:
             pk = user_info["sub"]
         except KeyError:
-            messages.error(self.request,
-                           _("Error: sub missing from keycloak roles"), )
-            return redirect(reverse("control:auth.login"))
+            raise SuspiciousOperation("Error: sub missing from keycloak roles")
+            #
+            # messages.error(self.request,
+            #                _("Error: sub missing from keycloak roles"), )
+            # return redirect(reverse("control:auth.login"))
 
         try:
             username = user_info["preferred_username"]
@@ -304,14 +307,15 @@ class OIDCAuthBackend(BaseAuthBackend):
                 set_on_creation={},
             )
         except EmailAddressTakenError:
-            messages.error(
-                self.request,
-                _(
-                    "We cannot create your user account as a user account in this system "
-                    "already exists with the same email address."
-                ),
-            )
-            return redirect(reverse("control:auth.login"))
+            raise SuspiciousOperation("We cannot create your user account as a user account in this system already exists with the same email address.")
+            # messages.error(
+            #     self.request,
+            #     _(
+            #         "We cannot create your user account as a user account in this system "
+            #         "already exists with the same email address."
+            #     ),
+            # )
+            # return redirect(reverse("control:auth.login"))
 
         # Update Organizer Units from Roles
         prev_roles = set(Organizer.objects.filter(
@@ -378,9 +382,10 @@ class OIDCAuthBackend(BaseAuthBackend):
         }
         r = requests.get(url, headers=headers)
         if r.status_code != 200:
-            messages.error(self.request,
-                           _("Error Gestor Eventos API"), )
-            return redirect(reverse("control:auth.login"))
+            raise SuspiciousOperation("Error Gestor Eventos API")
+            # messages.error(self.request,
+            #                _("Error Gestor Eventos API"), )
+            # return redirect(reverse("control:auth.login"))
 
         events = r.json()
 
